==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/datasync/kotlin/inputs/LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.datasync.kotlin.inputs

import com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property version The specific NFS version that you want DataSync to use for mounting your NFS share. Valid values: `NFS3`. Default: `NFS3`
 */
public data class LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs(
    public val version: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs> {
    override fun toJava():
        com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs =
        com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs.builder()
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs].
 */
@PulumiTagMarker
public class LocationFsxOntapFileSystemProtocolNfsMountOptionsArgsBuilder internal constructor() {
    private var version: Output<String>? = null

    /**
     * @param value The specific NFS version that you want DataSync to use for mounting your NFS share. Valid values: `NFS3`. Default: `NFS3`
     */
    @JvmName("mmevbuvjqgkwxafq")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value The specific NFS version that you want DataSync to use for mounting your NFS share. Valid values: `NFS3`. Default: `NFS3`
     */
    @JvmName("pidheynawjrsftxi")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs =
        LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs(
            version = version,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/datasync/kotlin/inputs/LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.datasync.kotlin.inputs

import com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property version
 */
public data class LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs(
    public val version: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs> {
    override fun toJava(): com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs =
        com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs.builder()
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs].
 */
@PulumiTagMarker
public class LocationFsxOntapFileSystemProtocolNfsMountOptionsArgsBuilder internal constructor() {
    private var version: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("bqobvcdukhtmrqum")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value
     */
    @JvmName("xifmrbxtnhumeowh")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs =
        LocationFsxOntapFileSystemProtocolNfsMountOptionsArgs(
            version = version,
        )
}
